@@ -191,7 +191,7 @@ class ToolkitCategory(Enum):
     Defines the categories for toolkits.
     """
 
-    WORKFLOWS = 1
+    FUNCTIONS = 1
     NODES = 2
 
 
