@@ -330,9 +330,7 @@ class Qctrl:
         Use another thread to check qctrl version.
         """
         for package in PackageRegistry:
-            if package.is_installed():
-                _ = package.import_pkg()
-                Thread(target=package.check_latest_version, daemon=True).start()
+            Thread(target=package.check_latest_version, daemon=True).start()
 
 
 @tenacity.retry(
