@@ -1,11 +1,11 @@
-# Copyright 2021 Q-CTRL. All rights reserved.
+# Copyright 2022 Q-CTRL. All rights reserved.
 #
 # Licensed under the Q-CTRL Terms of service (the "License"). Unauthorized
 # copying or use of this file, via any medium, is strictly prohibited.
 # Proprietary and confidential. You may not use this file except in compliance
 # with the License. You may obtain a copy of the License at
 #
-#     https://q-ctrl.com/terms
+#    https://q-ctrl.com/terms
 #
 # Unless required by applicable law or agreed to in writing, software
 # distributed under the License is distributed on an "AS IS" BASIS. See the
@@ -57,9 +57,7 @@ class BaseQuery(ABC):
         document = self.get_query_document()
         variable_values = self._get_variable_values(*args, **kwargs)
         return self._process(
-            document,
-            variable_values,
-            disable_result_cache=disable_result_cache,
+            document, variable_values, disable_result_cache=disable_result_cache
         )
 
     def get_query_document(self) -> DocumentNode:
